## Starting a Game

You can start a game with another user by typing

```
start with other user
```

or you can start a game with a computer with

```
start as <white or black> with computer
```

## Playing

After starting the game, you can make your move by typing

```
do <your move>
```

using [Standard Algebraic Chess Notation](https://goo.gl/rehi8n). For example,
`do e4` to move a pawn to *e4* or `do Nf3` to move a night to *f3* or `do O-O`
to castle.


## Ending the game

The bot will detect if a game is over. You can end one early by resigning
with the

```
resign
```

command.

(Or you could just stop responding.)
